@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.6001';
+our $VERSION = '0.70';
 
 use warnings;
 use strict;
@@ -40,9 +40,11 @@ sub populate {
     }
     elsif ($data_ref eq 'HASH') {
         for my $vertex (keys %$data) {
-            if ( $data->{$vertex}{label} ) {
-                my $label = delete $data->{$vertex}{label};
-                $self->set_vertex_attribute($vertex, 'label', $label);
+            for my $entry ( keys %{ $data->{$vertex} } ) {
+                if ( $entry !~ /\A\d+\z/ ) {
+                    my $label = delete $data->{$vertex}{$entry};
+                    $self->set_vertex_attribute($vertex, $entry, $label);
+                }
             }
             $self->_from_hash(
                 $vertex, $data->{$vertex}, $attr
@@ -217,7 +219,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.6001
+version 0.70
 
 =head1 SYNOPSIS
 
@@ -234,10 +236,12 @@ version 0.6001
  );
  for my $vertex (sort { $a <=> $b } $gw->vertices) {
     warn sprintf "vertex: %s weight=%.2f\n",
-        $vertex, $gw->get_cost($vertex);
-    for my $neighbor (sort { $a <=> $b } $gw->neighbors($vertex)) {
+        $vertex,
+        $gw->get_cost($vertex);
+    for my $successor (sort { $a <=> $b } $gw->successors($vertex)) {
         warn sprintf "\tedge to: %s weight=%.2f\n",
-            $neighbor, $gw->get_cost([$vertex, $neighbor]);
+            $successor,
+            $gw->get_cost([$vertex, $successor]);
     }
  }
 
@@ -260,10 +264,14 @@ version 0.6001
  for my $vertex (sort { $a <=> $b } $gw->vertices) {
     warn sprintf "%s vertex: %s %s=%.2f\n",
         $gw->get_vertex_attribute($vertex, 'label'),
-        $vertex, $attr, $gw->get_cost($vertex, $attr);
-    for my $neighbor (sort { $a <=> $b } $gw->neighbors($vertex)) {
+        $vertex,
+        $attr,
+        $gw->get_cost($vertex, $attr);
+    for my $successor (sort { $a <=> $b } $gw->successors($vertex)) {
         warn sprintf "\tedge to: %s %s=%.2f\n",
-            $neighbor, $attr, $gw->get_cost([$vertex, $neighbor], $attr);
+            $successor,
+            $attr,
+            $gw->get_cost([$vertex, $successor], $attr);
     }
  }
 
